Learn R Programming

AID (version 1.9)

confInt.boxcoxfr:

Description

confInt.boxcoxfr calculates mean and confidence interval for back transformed data in each group and plots their error bars with confidence intervals.

Usage

# S3 method for boxcoxfr
confInt(x, level = 0.95, plot = TRUE, xlab = NULL, ylab = NULL, title = NULL, 
  width = NULL, verbose = TRUE, ...)

Arguments

x
a boxcoxfr object.
level
the confidence level.
plot
a logical to plot error bars with confidence intervals.
xlab
a label for the x axis, defaults to a description of x.
ylab
a label for the y axis, defaults to a description of y.
title
a main title for the plot.
width
a numeric giving the width of the little lines at the tops and bottoms of the error bars (defaults to 0.15).
verbose
a logical for printing output to R console.
...
additional argument(s) for methods.

Value

Returns a matrix of output.

Details

Confidence interval in each group is constructed separately.

Examples

Run this code

library(AID)

data(AADT)
attach(AADT)
out <- boxcoxfr(aadt, class)
confInt(out, level = 0.95)

Run the code above in your browser using DataLab